General Repository Information
==============================

This repository contains the raw data and R-codes used in "Species divergence under competition and shared predation" (Roesti et al., Ecology Letters). If you are using any of these data or codes, please cite the original publication (Roesti et al.) as well as this repository. In case of questions, contact Marius Roesti (marius.roesti@unibe.ch; ORCID 0000-0002-7408-4804).


Overview of Data files and Codes
================================

data
* abiotic.lake.variation.csv
* diet.categories_bolnick.reanalysis.csv
* diet.categories_sculpin.csv
* diet.categories_stickleback.csv
* environmental.d15N.data.csv
* experimental.data_bolnick.reanalysis.csv
* landmark.data_sculpin.tps
* landmark.data_stickleback.tps
* landmark.matrix_sculpin.csv
* landmark.matrix_stickleback.csv
* morphology.data_sculpin.csv
* morphology.data_stickleback.csv
* morphology.population.means_sculpin.csv
* morphology.population.means_stickleback.csv
* stomach.contents_sculpin.csv
* stomach.contents_stickleback.csv
* trout&sculpin.diet_bolnick.reanalysis.csv

codes
* R.code_abiotic.variation.r
* R.code_body.shape.r
* R.code_morphological.traits.r
* R.code_reanalysis.bolnick.experiment.r
* R.code_stable.isotopes.r
* R.code_stomach.contents.r


Usage
=====

Download the Dryad repository and unzip the main folder containing the two subfolders 'data' and 'codes'. Before running an R-code, specify the working directory (i.e., the unzipped main repository folder). Codes were run using R version 4.1.1.


Data File Details
=================

Details for: "abiotic.lake.variation.csv"
-----------------------------------------

* Description: Abiotic characteristics (10 variables) of all study lakes.

* File format and dimensions: .csv, 27 rows x 14 columns

* Notable variables, abbreviations and measuring units:
  * area: lake surface area in hectares
  * perimeter: lake perimeter in meters
  * mean.depth: mean lake depth in meters
  * max.depth: maximal lake depth in meters
  * littoral.area: littoral zone in %
  * elevation: lake altitude in meters
  * SRP: soluble reactive phosphorus in uM
  * Na: sodium concentration in uM
  * Ca: calcium concentration in mg/l

* Missing data code: NA


Details for: "diet.categories_bolnick.reanalysis.csv"
-----------------------------------------------------

* Description: Reference file with prey categories in experimental stickleback from Bolnick et al. (2010), and how these categories relate to the prey categories as collected by Roesti et al. The data by Bolnick et al. (2010) were re-analyzed for Roesti et al.

* File format and dimensions: .csv, 28 rows x 3 columns

* Other notes: NA in the second column indicates that a prey category from Bolnick et al. could not be matched to any prey category as collected by Roesti et al. NA in the third column indicates that a prey species could not be assigned as either limnetic or benthic. The content of this file corresponds to Table 1 of the Supplementary Analysis 1 in Roesti et al.


Details for: "diet.categories_sculpin.csv"
------------------------------------------

* Description: Reference file with prey categories in sculpin.

* File format and dimensions: .csv, 36 rows x 3 columns

* Other notes: NA in the third column indicates that a prey species could not be clearly assigned as either limnetic or benthic. The content of this file corresponds to Supplementary Table S5 (Table S5) in Roesti et al.


Details for: "diet.categories_stickleback.csv"
----------------------------------------------

* Description: Reference file with prey categories in stickleback.

* File format and dimensions: .csv, 40 rows x 3 columns

* Other notes: NA in the third column indicates that a prey species could not be clearly assigned as either limnetic or benthic.  The content of this file corresponds to Supplementary Table S4 (Table S4) in Roesti et al.


Details for: "environmental.d15N.data.csv"
------------------------------------------

* Description: d15N stable isotope signature of a mussle and/or a snail sample, or the average of both if available, for each study lake. Used as a baseline reference for each lake when testing for a difference in d15N between sympatric and allopatric populations within each species.

* File format and dimensions: .csv, 27 rows x 5 columns

* Notable variables, abbreviations and measuring units:
  * d15N = measure of the ratio of the two stable isotopes of nitrogen (15N:14N)

* Missing data code: NA


Details for: "experimental.data_bolnick.reanalysis.csv"
-------------------------------------------------------

* Description: Data file with counts of prey specimens for each prey category in stomach contents of experimental stickleback from Bolnick et al. (2010). These data were re-analyzed for Roesti et al.

* File format and dimensions: .csv, 655 rows x 49 columns

* Notable variables, abbreviations and measuring units:
  * Trap: concatenated information on 'Block' and 'Competition treatment' (St = stickleback, Sc = sculpin, Tr = trout)
  * Mass in grams
  * Standard length: in millimeters


Details for: "landmark.data_sculpin.tps"
----------------------------------------

* Description: Landmark data of all sculpin specimens used for geometric morphometrics analysis of body shape variation.

* File format and dimensions: .tps, 392 specimens, 19 landmarks with one x and one y coordinate each

* Other notes: Landmark coordinates are scaled. Supplementary Figure 3 (Figure S3) in Roesti et al. provides detailed information on the location of each landmark.


Details for: "landmark.data_stickleback.tps"
--------------------------------------------

* Description: Landmark data of all stickleback specimens used for geometric morphometric analysis of body shape variation. 

* File format and dimensions: .tps, 335 specimens, 21 landmarks with one x and one y coordinate each

* Other notes: Landmark coordinates are scaled. Supplementary Figure 3 (Figure S3) in Roesti et al. provides detailed information on the location of each landmark.


Details for: "landmark.matrix_sculpin.csv"
------------------------------------------

* Description: Landmark matrix (pairwise landmark connections) for visualizing body shape differences between allopatric and sympatric sculpin using the R-package geomorph.

* File format and dimensions: .csv, 18 rows x 2 columns


Details for: "landmark.matrix_stickleback.csv"
----------------------------------------------

* Description: Landmark matrix (pairwise landmark connections) for visualizing body shape differences between allopatric and sympatric stickleback using the R-package geomorph.

* File format and dimensions: .csv, 19 rows x 2 columns


Details for: "morphology.data_sculpin.csv"
------------------------------------------

* Description: Data file with raw morphological trait measurements of sculpin.

* File format and dimensions: .csv, 415 rows x 21 columns

* Notable variables, abbreviations and measuring units:
  * type: lake type, either allo (= allopatric) or sym (= sympatric)
  * SL: standard length in millimeters
  * max.soak.time_h: soaking time in hours of the minnow trap in which each individual was caught. If 0, then the individual was caught with a dip net.
  * sex: either f (= female) or m (= male)
  * d15N: measure of the ratio of the two stable isotopes of nitrogen (15N:14N)
  * Preop.spine.length: preopercular spine length
  * GR: gill raker

* Other notes: All length and width measurements are in millimeters. Fin areas are in mm^2.

* Missing data code: NA


Details for: "morphology.data_stickleback.csv"
----------------------------------------------

* Description: Data file with raw morphological trait measurements of stickleback.

* File format and dimensions: .csv, 440 rows x 18 columns

* Notable variables, abbreviations and measuring units:
  * type: lake type, either allo (= allopatric) or sym (= sympatric)
  * SL: standard length in millimeters
  * max.soak.time_h: soaking time in hours of the minnow trap in which each individual was caught. If 0, then the individual was caught with a dip net.
  * sex: either f (= female) or m (= male)
  * d15N: measure of the ratio of the two stable isotopes of nitrogen (15N:14N)
  * GR: gill raker

* Other notes: All length measurements are in millimeters.

* Missing data code: NA


Details for: "morphology.population.means_sculpin.csv"
------------------------------------------------------

* Description: Data file with population means of each morphological trait after size correction, as well as of PC1 and PC2 values of a PCA run separately for all foraging and for all antipredator traits in sculpin.

* File format and dimensions: .csv, 18 rows x 18 columns

* Notable variables, abbreviations and measuring units:
  * lake.type: lake type, either allo (= allopatric) or sym (= sympatric)
  * Preop.spine.length: preopercular spine length
  * GR: gill raker
  * pc1: principal component axis 1
  * pc2: principal component axis 2
  
* Other notes: Population means of size-corrected trait values were calculated from raw trait values using the code "R.code_morphological.traits.r". All length and width measurements are in millimeters after size correction. Fin areas are in mm^2 after size correction. Principal component analyses were run for log-transformed and size-corrected population means of all four foraging traits (gill raker number, gill raker length, premaxilla length, gape width) as well as all eight antipredator traits (dorsal spine length, pelvic spine length, preopercular spine length, caudal fin area, dorsal fin area, peduncle depth, body width).


Details for: "morphology.population.means_stickleback.csv"
----------------------------------------------------------

* Description: Data file with population means of each morphological trait after size correction, as well as of PC1 and PC2 values of a PCA run separately for all foraging and for all antipredator traits in stickleback.

* File format and dimensions: .csv, 19 rows x 14 columns

* Notable variables, abbreviations and measuring units:
  * lake.type: lake type, either allo (= allopatric) or sym (= sympatric)
  * GR: gill raker
  * pc1: principal component axis 1
  * pc2: principal component axis 2
  
* Other notes: Population means of size-corrected trait values were calculated from raw trait values using the code "R.code_morphological.traits.r". All length and width measurements are in millimeters after size correction. Principal component analyses were run for log-transformed and size-corrected population means of all four foraging traits (gill raker number, gill raker length, premaxilla length, gape width) as well as all four antipredator traits (dorsal spine length, pelvic spine length, pelvic girdle length, plate number).


Details for: "stomach.contents_sculpin.csv"
-------------------------------------------

* Description: Data file with counts of prey specimens for each prey category in stomach contents of sculpin.

* File format and dimensions: .csv, 255 rows x 40 columns

* Notable variables, abbreviations and measuring units:
  * lake.type: lake type, either allo (= allopatric) or sym (= sympatric)
  * SL: standard length in millimeters
  * max.soak.time_h: soaking time in hours of the minnow trap in which each individual was caught. If 0, then the individual was caught with a dip net.
  
* Other notes: Only individuals with non-empty stomachs and identifiable prey items are included.


Details for: "stomach.contents_stickleback.csv"
-----------------------------------------------

* Description: Data file with counts of prey specimens for each prey category in stomach contents of stickleback.

* File format and dimensions: .csv, 280 rows x 40 columns

* Notable variables, abbreviations and measuring units:
  * lake.type: lake type, either allo (= allopatric) or sym (= sympatric)
  * SL: standard length in millimeters
  * max.soak.time_h: soaking time in hours of the minnow trap in which each individual was caught. If 0, then the individual was caught with a dip net.
  
* Other notes: Only individuals with non-empty stomachs and identifiable prey items are included.


Details for: "trout&sculpin.diet_bolnick.reanalysis.csv"
--------------------------------------------------------

* Description: Data file with counts of prey specimens for each prey category in stomach contents of 16 sculpin and 20 trout specimens from Bolnick et al. (2010). These data were re-analyzed for Roesti et al.

* File format and dimensions: .csv, 37 rows x 22 columns

* Notable variables, abbreviations and measuring units:
  * Mass_g: Weight in grams 
  * SL_mm: standard length, in millimeters
  


Code Details
============

Details for: "R.code_abiotic.variation.r"
-----------------------------------------

* Description: R-code for analyzing and visualizing abiotic variation among study lakes and how this variation may possibly affect phenotypic shifts between allopatric and sympatric populations in sculpin and stickleback.

* Required data files to run code:
  * abiotic.lake.variation.csv
  * morphology.population.means_stickleback.csv
  * morphology.population.means_sculpin.csv

* Associated analysis in the manuscript: Supplementary Analysis 2


Details for: "R.code_body.shape.r"
----------------------------------

* Description: R-code for analyzing and visualizing body shape shifts between allopatric and sympatric populations in sculpin and stickleback using landmark data.

* Required data files to run code: 
  * landmark.data_stickleback.tps
  * landmark.matrix_stickleback.csv
  * landmark.data_sculpin.tps
  * landmark.matrix_sculpin.csv

* Associated figures in the manuscript: Figure 4, Figure S3, Figure S5 


Details for: "R.code_morphological.traits.r"
--------------------------------------------

* Description: R-code for analyzing and visualizing morphological trait shifts between allopatric and sympatric populations in sculpin and stickleback.

* Required data files to run code: 
  * morphology.data_stickleback.csv
  * morphology.population.means_stickleback.csv
  * morphology.data_sculpin.csv
  * morphology.population.means_sculpin.csv
  
* Associated figures in the manuscript: Figure 2, Figure 3, Figure S2, Figure S4, Figure S8


Details for: "R.code_reanalysis.bolnick.experiment.r"
-----------------------------------------------------

* Description: R-code for re-analyzing data from the field experiment by Bolnick et al. (2010), testing for how sculpin and tout competition affects stickleback foraging.

* Required data files to run code: 
  * diet.categories_bolnick.reanalysis.csv
  * experimental.data_bolnick.reanalysis.csv
  * trout&sculpin.diet_bolnick.reanalysis.csv
  
* Associated analysis in the manuscript: Supplementary Analysis 1


Details for: "R.code_stable.isotopes.r"
---------------------------------------

* Description: R-code for analyzing and visualizing d15N stable isotope shifts between allopatric and sympatric populations in sculpin and stickleback, and whether these shifts are associated with foraging trait variation. Code also analyses and visualises
d15N-based niche width differences between allopatric and sympatric populations within each species.

* Required data files to run code: 
  * environmental.d15N.data.csv
  * morphology.population.means_stickleback.csv
  * morphology.data_stickleback.csv
  * morphology.population.means_sculpin.csv
  * morphology.data_sculpin.csv
  
* Associated figures in the manuscript: Figure 5c, Figure S6, Figure S7


Details for: "R.code_stomach.contents.r"
----------------------------------------

* Description: R-code for analyzing and visualizing shifts in diet (stomach contents) between allopatric and sympatric populations in sculpin or stickleback.

* Required data files to run code: 
  * stomach.contents_stickleback.csv
  * stomach.contents_sculpin.csv
  * diet.categories_stickleback.csv
  * diet.categories_sculpin.csv
  
* Associated figures in the manuscript:  Figure 5a, Figure 5c, Figure 5d


===
END